@@ -2,10 +2,11 @@
 
 use criterion::{black_box, criterion_group, criterion_main, BenchmarkId, Criterion, Throughput};
 use glass_pumpkin::safe_prime::from_rng;
+use openssl::bn::BigNum;
 use rand::rngs;
 use rand_core::OsRng;
 use scicrypt_numbertheory::gen_safe_prime;
-use scicrypt_traits::randomness::SecureRng;
+use scicrypt_traits::randomness::GeneralRng;
 
 pub fn safe_prime_benchmark(c: &mut Criterion) {
     let mut group = c.benchmark_group("safe_prime_benchmark");
@@ -15,7 +16,7 @@ pub fn safe_prime_benchmark(c: &mut Criterion) {
         //group.throughput(Throughput::Bytes(*bit_length as u64));
 
         // Benchmark our `gen_safe_prime` function
-        let mut rng = SecureRng::new(OsRng);
+        let mut rng = GeneralRng::new(OsRng);
         group.bench_with_input(
             BenchmarkId::new("gen_safe_prime", bit_length),
             bit_length,
@@ -33,6 +34,19 @@ pub fn safe_prime_benchmark(c: &mut Criterion) {
                 b.iter(|| from_rng(black_box(bits), &mut rng));
             },
         );
+
+        // Benchmark `openssl`'s safe prime generation
+        let mut rng = rand::rngs::OsRng;
+        group.bench_with_input(
+            BenchmarkId::new("openssl", bit_length),
+            bit_length,
+            |b, &bits| {
+                b.iter(|| {
+                    let mut big = BigNum::new().unwrap();
+                    big.generate_prime(bits as i32, true, None, None);
+                });
+            },
+        );
     }
 
     group.finish();
